# BennyCloth

The name BennyCloth is a combination of **Benny** the Beaver and a **synonym for Canvas**, whose [REST API](https://canvas.instructure.com/doc/api/index.html) was the means for delivering homework assignments, randomized using many of the functions in this package.

BennyCloth is available on [pypi](https://pypi.org/project/bennycloth/)

## Packages

+ `loads`

+ `steel`

+ `concrete`

+ `wood`

+ `canvas`

+ `matrix`

+ `beaverFrame`

### Tutorials

Tutorials used in figuring out how to make a Python package then deploy it to [pypi](https://pypi.org/)

+ https://towardsdatascience.com/create-your-own-python-package-and-publish-it-into-pypi-9306a29bc116

+ https://packaging.python.org/en/latest/guides/distributing-packages-using-setuptools/

+ https://packaging.python.org/en/latest/tutorials/packaging-projects/

+ https://www.freecodecamp.org/news/how-to-create-and-upload-your-first-python-package-to-pypi/

+ https://www.freecodecamp.org/news/build-your-first-python-package/

+ https://medium.com/@udiyosovzon/things-you-should-know-when-developing-python-package-5fefc1ea3606
